{
 "cells": [
  {
   "cell_type": "code",
   "execution_count": 1,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "# Tiina Manninen\n",
    "# Implementation of astrocyte model by Lavrentovich and Hemkin (2008)\n",
    "# Lavrentovich, M. and Hemkin, S. (2008). A mathematical model of spontaneous \n",
    "# calcium (II) oscillations in astrocytes. J. Theor. Biol. 251, 553–560.\n",
    "# Corrigendum available: Lavrentovich, M. and Hemkin, S. (2009). J. Theor. Biol. 260, 332.\n",
    "\n",
    "# Model implemented and ran using Jupyter Notebook.\n",
    "\n",
    "# Model code used in publication: Manninen, T., Havela, R., and Linne, M.-L. (2017). \n",
    "# Reproducibility and comparability of computational models for astrocyte calcium excitability.\n",
    "# Front. Neuroinform.\n",
    "\n",
    "import numpy as np\n",
    "\n",
    "class ModelSystem:\n",
    "    def __init__(self, params):\n",
    "        self.params = params\n",
    "    \n",
    "    def computeDeriv(self, state, t):\n",
    "        Ca, Ca_ER, IP3 = state\n",
    "        modelPar = self.params\n",
    "        \n",
    "        # Intermediate variables\n",
    "        v_SERCA = modelPar.v_M2 * Ca ** 2 / (Ca ** 2 + modelPar.k_2 ** 2)\n",
    "        v_PLC = modelPar.v_p * Ca ** 2 / (Ca ** 2 + modelPar.k_p ** 2)\n",
    "        v_CICR = 4 * modelPar.v_M3 * modelPar.k_CaA ** modelPar.n * Ca ** modelPar.n \\\n",
    "                    / ( (Ca ** modelPar.n + modelPar.k_CaA ** modelPar.n) \\\n",
    "                    * (Ca ** modelPar.n + modelPar.k_CaI ** modelPar.n) )\\\n",
    "                * IP3 ** modelPar.m \\\n",
    "                    / ( (IP3 ** modelPar.m + modelPar.k_IP3 ** modelPar.m) )\\\n",
    "                * (Ca_ER - Ca)\n",
    "                \n",
    "        # dx/dt \n",
    "        dCa_per_dt = modelPar.v_in - modelPar.k_out * Ca + v_CICR - v_SERCA \\\n",
    "                    + modelPar.k_f * (Ca_ER - Ca)\n",
    "        dCa_ER_per_dt = v_SERCA - v_CICR - modelPar.k_f * (Ca_ER - Ca)\n",
    "        dIP3_per_dt = v_PLC - modelPar.k_deg * IP3\n",
    "        \n",
    "        deriv = [dCa_per_dt, dCa_ER_per_dt, dIP3_per_dt]\n",
    "        return deriv   "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 2,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "class ModelParameters:\n",
    "    k_2 = 0.1     # uM\n",
    "    k_CaA = 0.15  # uM \n",
    "    k_CaI = 0.15  # uM\n",
    "    k_deg = 0.08  # 1/s\n",
    "    k_f = 0.5     # 1/s\n",
    "    k_IP3 = 0.1   # uM\n",
    "    k_out = 0.5   # 1/s\n",
    "    k_p = 0.3     # uM\n",
    "    m = 2.2\n",
    "    n = 2.02\n",
    "    v_in = 0.05   # uM/s \n",
    "    v_M2 = 15     # uM/s \n",
    "    v_M3 = 40     # 1/s\n",
    "    v_p = 0.05    # uM/s"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 3,
   "metadata": {
    "collapsed": false,
    "scrolled": false
   },
   "outputs": [],
   "source": [
    "params = ModelParameters()\n",
    "mySys = ModelSystem(params)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 4,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "from scipy.integrate import odeint\n",
    "initial = [0.1, 1.5, 0.1] # uM\n",
    "\n",
    "Tmax = 600\n",
    "dt = 0.1\n",
    "t = np.arange(0,Tmax,dt)\n",
    "\n",
    "data = odeint(mySys.computeDeriv, initial, t)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 5,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Populating the interactive namespace from numpy and matplotlib\n"
     ]
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAA3oAAAJPCAYAAAAqk6bSAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nSZKknrHQkyRJkqSesdCTJEmSpJ75f7ufaW4W6HGQAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f215febe940>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%pylab inline\n",
    "import matplotlib.pyplot as plt\n",
    "\n",
    "plt.figure(figsize=(9, 6), dpi=200)\n",
    "plt.subplot(3,1,1)\n",
    "plt.plot(t, data[:,0])\n",
    "plt.title('Calcium concentration')\n",
    "plt.ylabel('Ca (uM)')\n",
    "\n",
    "plt.subplot(3,1,2)\n",
    "plt.plot(t, data[:,2])\n",
    "plt.title('IP3 concentration')\n",
    "plt.ylabel('IP3 (uM)')\n",
    "\n",
    "plt.subplot(3,1,3)\n",
    "plt.plot(t, data[:,1])\n",
    "plt.title('Calcium concentration in the ER')\n",
    "plt.ylabel('CaER (uM)')\n",
    "plt.xlabel('t (s)',)\n",
    "plt.tight_layout()\n",
    "\n",
    "\n",
    "np.savetxt('Lavrentovich2008.csv', (t, data[:,0], data[:,1], data[:,2]), delimiter=',')"
   ]
  }
 ],
 "metadata": {
  "anaconda-cloud": {},
  "kernelspec": {
   "display_name": "Python [default]",
   "language": "python",
   "name": "python3"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 3
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython3",
   "version": "3.5.2"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 1
}
